# Web3MQ-SDK-Python
web3mq python sdk v1

## Install

```bash
pip install web3mq
```

## Feature

- user
- room
- contact
- message


## Init client

```python
from web3mq.client import Web3mqClient

# default env is prod
prod_client = Web3mqClient()

# you can use test env
test_client = Web3mqClient(env='test')
```

## User api

*user register*

```python
from web3mq.client import Web3mqClient

client = Web3mqClient()
# User's ETH wallet address, get it by MetaMask's API
wallet_address = "your wallet address"

# platform options twitter/instagram/facebook/discord

platform = 'twitter'
username = 'your username in previou platform'

result = client.do_register(wallet_address, platform, username)

# result example
{
    'user_id': 'user_id',
    'nick_name': 'nickname',
    'twitter_username': 'nickname',
    'twitter_avatar': '',
    'instagram_username': '',
    'instagram_avatar': '',
    'facebook_username': '',
    'facebook_avatar': '',
    'discord_username': '',
    'discord_avatar': '',
    'opensea_username': '',
    'opensea_avatar': '',
    'eth_wallet_address': '',
    'ens_name': '',
    'status': '0000000',
    'created_at': 1653377732583874437
}
```

*Get login login_random_secret*

```python
from web3mq.client import Web3mqClient

client = Web3mqClient()

wallet_address = "your wallet address"

login_random_secret = client.login_random_secret(wallet_address)
```

*user login*

```python
from web3mq.client import Web3mqClient

client = Web3mqClient()

#  User's login random secret, get it from get_login_random_secret function
login_random_secret = "login random secret"
wallet_address = "your wallet address"

# Generated by MetaMask-Sign with user's random login secret
signature = "signature"

client.do_login(login_random_secret, signature, wallet_address)
```

*Get user info*

```python
from web3mq.client import Web3mqClient

client = Web3mqClient()

# platform options twitter/instagram/facebook/discord
platform = "twitter"

# User's username on the platform
username = "username"

userinfo = client.get_user_info(platform, username)
```

## Room api

*Create chat room*

> Create a chat room by specifying users

```python
from web3mq.client import Web3mqClient

client = Web3mqClient()


user_ids = ["user_id"]

client.create_chat_room(user_ids)
```

*Get room info*

```python
from web3mq.client import Web3mqClient

client = Web3mqClient()
room_id = "room_id"

client.get_room_info(room_id)
```

*Get room list*

> Get all rooms' id that you are participating in

```python
from web3mq.client import Web3mqClient

client = Web3mqClient()

client.get_my_rooms()
```

*Get my_chats*

```python
from web3mq.client import Web3mqClient

client = Web3mqClient()
page = 1
size = 10

client.get_my_chats(page, size)
```

## Contact api

*Add user to your contact*

> Add an user to your contact list by user's OID

```python
from web3mq.client import Web3mqClient

client = Web3mqClient()

user_id = "user_id"
client.add_user_to_my_contact(user_id)
```


*Get my_contact*

```python
from web3mq.client import Web3mqClient

client = Web3mqClient()
page = 1
size = 10

client.get_my_contact(page, size)
```
